# vistats
Visualization for statistical tests.

## Background
We would like to 
write a line and asterisks between bars when we get a statistically significant difference by a statistical test. However, there is no appropriate package for visualizing them with 'matplotlib'. This package provides them.

## Installation

```
pip install vistats
```

## Usage
Please see [here](https://github.com/takato86/vistats/blob/main/examples/barplot_example.ipynb)
